#include <kernel.h>
#include <t_syslog.h>
#include <t_stdlib.h>
#include "syssvc/serial.h"
#include "syssvc/syslog.h"
#include "kernel_cfg.h"

#include "arduino_app.h"
#include "arduino_main.h"

/* GR-PEACH Sketch Template V1.00 */
#include <Arduino.h>

#define MotorPin1 20
#define MotorPin2 21
#define ChangeSpWidth 1
#define ChangePerSec 2
#define OnePlacePin 51
#define TenPlacePin 50

int motor_sp = 60;
int rot_sp = 20;

const int d_in_photo = 52;
int start_msec = millis();
int current_val = 0;
int cnt = 0;
int current_cnt = 0;
int loop2_cnt = 0;

int place_pin[2] = {TenPlacePin,OnePlacePin};
int place_pin_val[2][2] = {{0,1},{1,0}};
int seg_pin[7] = {38,39,41,43,37,40,42};
int seg_val[10][7] = {{0,0,0,0,0,0,1},
 					{1,0,0,1,1,1,1},
					{0,0,1,0,0,1,0},
					{0,0,0,0,1,1,0},
					{1,0,0,1,1,0,0},
					{0,1,0,0,1,0,0},
 					{0,1,0,0,0,0,0},
 					{0,0,0,1,1,1,1},
					{0,0,0,0,0,0,0},
 					{0,0,0,0,1,0,0}};

void setup()
{
    
	pinMode(MotorPin1,OUTPUT);
    pinMode(MotorPin2,OUTPUT);
    pinMode(d_in_photo, INPUT);
    for(int i=0;i<7;i++){
    pinMode(seg_pin[i],OUTPUT);
    }
    pinMode(OnePlacePin,OUTPUT);
    pinMode(TenPlacePin,OUTPUT);
    Serial.begin(115200);
    
}

/*
 *  7セグメントを光らせるための関数
 */
void seg_digital_write(int seg_val_num,int place_num){
	
	for(int i=0;i<7;i++){
		digitalWrite(seg_pin[i],seg_val[seg_val_num][i]);
	}
	for(int j=0;j<2;j++){
		digitalWrite(place_pin[j],place_pin_val[place_num][j]);
	}
}


/*
 *  モータを動かす
 */
void loop()
{

    analogWrite(MotorPin1,motor_sp);
    digitalWrite(MotorPin2,LOW);
    
}

/*
 *  フォトインタラプタで信号を検出し回転数を求める
 */
void loop1(){
    int val = digitalRead(d_in_photo);
    start_msec++;
    if(val != current_val){
    	current_val = val;
    	cnt++;
    }
    if((millis()-start_msec) > 1000){
    	cnt = cnt/2;
    	Serial.println(cnt);
    	start_msec = millis();
    	current_cnt = cnt;
    	cnt = 0;
    	loop2_cnt = 0;
    }
    delay(1);
}


/*
 *  モータの速度を制御する
 */
void loop2(){
	if(loop2_cnt < ChangePerSec){
   if(current_cnt != 0){
   	if(rot_sp > current_cnt-2){
   		Serial.println(">");
   		motor_sp+=ChangeSpWidth;
   	}else if(rot_sp < current_cnt+2){
   		Serial.println("<");
   		motor_sp-=ChangeSpWidth;
   	}else{
   		Serial.println("=");
   	}
   	loop2_cnt++;
   }
	}
	dly_tsk(1);
}

/*
 *  7セグメントに回転数を表示する
 */
void loop3(){
	seg_digital_write(current_cnt%10,0);
	delay(1);
	seg_digital_write(current_cnt/10,1);	
	delay(1);
}
/*
 *  Cyclic Handler
 * 
 *  This handler is called every 10 [ms] as specified in
 *  multitask_arduino.cfg.
 */
void cyclic_handler(intptr_t exinf) {
	irot_rdq(LOOP_PRI); /* change the running loop. */
}
